==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/sr.js <==
﻿/*
 * Serbian language file.
 *
 * Author: Zoltan Csala (zcsala021 at gmail dot com)
 */

var theUILang =
{
 General			: "Опште",
 Downloads			: "Низтовари",
 Connection			: "Веза",
 BitTorrent			: "BitTorrent",
 Advanced			: "Напредно",
 User_Interface 		: "Кориснички интерфејс",
 Confirm_del_torr		: "Confirm when deleting torrents",
 Update_GUI_every		: "Освежи графички интерфејс сваких",
 ms				: "милисекунди",
 Alt_list_bckgnd		: "Наизменично бојење редова у листи",
 Show_cat_start 		: "Покажи категорије на почетку",
 Show_det_start 		: "Покажи детаље на почетку",
 Dnt_start_down_auto		: "Don't start the download automatically",
 Listening_Port 		: "Listening Port",
 Port_f_incom_conns		: "Port used for incoming connections",
 Rnd_port_torr_start		: "Randomize port each time rTorrent starts",
 Type				: "Type",
 Bandwidth_Limiting		: "Bandwidth Limiting",
 Global_max_upl 		: "Global maximum upload rate",
 unlimited			: "неограничено",
 Glob_max_downl 		: "Global maximum download rate",
 Add_bittor_featrs		: "Additional BitTorrent Features",
 En_DHT_ntw			: "Enable DHT Network",
 Peer_exch			: "Peer Exchange",
 Ip_report_track		: "IP/Hostname to report to tracker",
 Disabled			: "Disabled",
 Enabled			: "Enabled",
 ruTorrent_settings		: "Settings",
 Doesnt_support 		: "ruTorrent does not support your browser.",
 Name				: "Име",
 Status 			: "Статус",
 Size				: "Величина",
 Done				: "Готово",
 Downloaded			: "Низтоварено",
 Uploaded			: "Узтоварено",
 Ratio				: "Однос",
 DL				: "DL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Ознака",
 Peers				: "Парњаци",
 Seeds				: "Сејачи",
 Remaining			: "Преостало",
 Priority			: "Приоритет",
 Not_torrent_file		: "Датотека мора бити torrent датотека.",
 Pausing			: "Заустављено",
 Seeding			: "Сејање",
 Downloading			: "Низтоварање",
 Checking			: "Проверавање",
 Error				: "Грешка",
 Queued 			: "Стављено у ред",
 Finished			: "Завршени",
 Stopped			: "Заустављено",
 Request_timed_out		: "The request to rTorrent has timed out.",
 Start				: "Почни",
 Pause				: "Паузирај",
 Stop				: "Заустави",
 Force_recheck			: "Force Recheck",
 New_label			: "Нова ознака ...",
 Remove_label			: "Уклони ознаку",
 Labels 			: "Ознаке",
 Remove 			: "Уклони",
 Delete_data			: "Уклони податке",
 Remove_and			: "Remove and...",
 Details			: "Детаљи ...",
 Properties			: "Својства ...",
 of				: "од", //this two creates line
 connected			: "повезано", //  XX of YY connected
 High_priority			: "Висок",
 Normal_priority		: "Нормалан",
 Low_priority			: "Низак",
 Dont_download			: "Немој да низтовараш",
 Files				: "Датотеке",
 Logger 			: "Дневник",
 s				: "с", // part of "KB/s"
 bytes				: "бајтова",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Учитавање ...",
 Torrent_file			: "Торент датотека",
 Torrent_URL			: "Torrent URL",
 Torrent_properties		: "Својства торента",
 Trackers			: "Трекери",
 Bandwidth_sett 		: "Bandwidth Settings",
 Number_ul_slots		: "Number of upload slots",
 Peer_ex			: "Парњачка размена",
 Enter_label_prom		: "Enter the new label for the selected torrents",
 Remove_torrents		: "Remove Torrent(s)",
 Rem_torrents_prompt		: "Do you really want to remove the selected torrent(s)?",
 All				: "Све",
 Active 			: "Активни",
 Inactive			: "Неактивни",
 No_label			: "Без ознаке",
 Transfer			: "Пренос",
 Time_el			: "Протекло време",
 Share_ratio			: "Однос дељења",
 Down_speed			: "Брзина низтовара",
 Ul_speed			: "Брзина узтовара",
 Wasted 			: "Страћено",
 Tracker			: "Трекер",
 Track_URL			: "URL трекера",
 Track_status			: "Статус трекера",
 Save_as			: "Снима се као",
 Created_on			: "Направљено",
 Comment			: "Коментар",
 add_button			: "Додај датотеку",
 add_url			: "Додај URL",
 ok				: "У реду",
 Cancel 			: "Одустани",
 mnu_add			: "Додај торент ",
 mnu_remove			: "Уклони",
 mnu_start			: "Покрени",
 mnu_pause			: "Паузирај",
 mnu_stop			: "Заустави",
 mnu_rss			: "RSS Downloader",
 mnu_settings			: "Подешавања ",
 mnu_search			: "Претрага ",
 mnu_lang			: "Језик",
 torrent_add			: "Додај торент", /*Caption of torrent add box*/
 time_w 			: "н ", /*for x weeks*/
 time_d 			: "д ", /*for x days remaining*/
 time_h 			: "ч ", /*for x hours remaining*/
 time_m 			: "м ", /*for x minutes remaining*/
 time_s 			: "с ", /*for x seconds remaining*/
 Base_directory 		: "Директоријум",
 Number_Peers_min		: "Најмањи број парњака",
 Number_Peers_max		: "Највећи број парњака",
 Tracker_Numwant		: "Жељени број парњака",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting 		: "Друга ограничења",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Максимална потрошња меморије",
 Glob_max_files 		: "Максималан број отворених датотека",
 Glob_max_http			: "Максималан број отворених НТТР веза",
 Other_sett			: "Друго",
 Directory_For_Dl		: "Подразумевани директоријум за низтоваре",
 Check_hash			: "Провери хеш после низтовара",
 Hash				: "Хеш",
 DisableTracker 		: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Клијент",
 Flags				: "Ознаке",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Помоћ",
 Speed				: "Брзина",
 Dont_add_tname 		: "Don't add torrent's name to path",
 Free_Disk_Space		: "Слободан простор на диску",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath 		: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "О програму",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList 			: "као листу",
 AsTree 			: "као стабло",
 Group				: "Група",
 SuperSeed			: "Супер-сејање",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Укупно",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Додаци",
 plgName			: "Име",
 plgStatus			: "Статус",
 plgLoaded			: "Учитан",
 plgDisabled			: "Not loaded",
 plgVersion			: "Верзија",
 plgAuthor			: "Аутор",
 plgDescr			: "Опис",
 mnu_go 			: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Брзи наставак",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Ограничење",
 speedList			: "Speed Popup List (comma-separated)",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Прикажи садржај табеле приликом померања",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser 		: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast 		: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No 			: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details 		: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 badTempPath 			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue files recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/lang/sr.js <==
﻿/*
 * Serbian language file.
 *
 * Author: Zoltan Csala (zcsala021 at gmail dot com)
 */

var theUILang =
{
 General			: "Опште",
 Downloads			: "Низтовари",
 Connection			: "Веза",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Напредно",
 User_Interface			: "Кориснички интерфејс",
 Confirm_del_torr		: "Confirm when deleting torrents",
 Update_GUI_every		: "Освежи графички интерфејс сваких",
 ms				: "милисекунди",
 Alt_list_bckgnd		: "Наизменично бојење редова у листи",
 Show_cat_start			: "Покажи категорије на почетку",
 Show_det_start			: "Покажи детаље на почетку",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "Don't start the download automatically",
 Listening_Port			: "Listening Port",
 Port_f_incom_conns		: "Port used for incoming connections",
 Rnd_port_torr_start		: "Randomize port each time rTorrent starts",
 Type				: "Type",
 Bandwidth_Limiting		: "Bandwidth Limiting",
 Global_max_upl			: "Global maximum upload rate",
 unlimited			: "неограничено",
 Glob_max_downl			: "Global maximum download rate",
 Add_bittor_featrs		: "Additional BitTorrent Features",
 En_DHT_ntw			: "Enable DHT Network",
 Peer_exch			: "Peer Exchange",
 Ip_report_track		: "IP/Hostname to report to tracker",
 Disabled			: "Disabled",
 Enabled			: "Enabled",
 ruTorrent_settings		: "Settings",
 Doesnt_support			: "ruTorrent does not support your browser.",
 Name				: "Име",
 Status				: "Статус",
 Size				: "Величина",
 Done				: "Готово",
 Downloaded			: "Низтоварено",
 Uploaded			: "Узтоварено",
 Ratio				: "Однос",
 DL				: "DL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Ознака",
 Peers				: "Парњаци",
 Seeds				: "Сејачи",
 Remaining			: "Преостало",
 Priority			: "Приоритет",
 Not_torrent_file		: "Датотека мора бити torrent датотека.",
 Pausing			: "Заустављено",
 Seeding			: "Сејање",
 Downloading			: "Низтоварање",
 Checking			: "Проверавање",
 Error				: "Грешка",
 Queued				: "Стављено у ред",
 Finished			: "Завршени",
 Stopped			: "Заустављено",
 Request_timed_out		: "The request to rTorrent has timed out.",
 Start				: "Почни",
 Pause				: "Паузирај",
 Stop				: "Заустави",
 Force_recheck			: "Force Recheck",
 New_label			: "Нова ознака...",
 Remove_label			: "Уклони ознаку",
 Labels				: "Ознаке",
 Remove				: "Уклони",
 Delete_data			: "Уклони податке",
 Remove_and			: "Remove And",
 Details			: "Детаљи...",
 Properties			: "Својства...",
 of				: "од", // this two creates line
 connected			: "повезано", // XX of YY connected
 High_priority			: "Висок",
 Normal_priority		: "Нормалан",
 Low_priority			: "Низак",
 Dont_download			: "Немој да низтовараш",
 Files				: "Датотеке",
 Logger				: "Дневник",
 s				: "с", // part of "KB/s"
 bytes				: "бајтова",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Учитавање...",
 Torrent_file			: "Торент датотека",
 Torrent_URL			: "Torrent URL",
 Torrent_properties		: "Својства торента",
 Trackers			: "Трекери",
 Bandwidth_sett			: "Bandwidth Settings",
 Number_ul_slots		: "Number of upload slots",
 Peer_ex			: "Парњачка размена",
 Enter_label_prom		: "Enter the new label for the selected torrents",
 Remove_torrents		: "Remove Torrent(s)",
 Rem_torrents_prompt		: "Do you really want to remove the selected torrent(s)?",
 All				: "Све",
 Active				: "Активни",
 Inactive			: "Неактивни",
 No_label			: "Без ознаке",
 Transfer			: "Пренос",
 Time_el			: "Протекло време",
 Share_ratio			: "Однос дељења",
 Down_speed			: "Брзина низтовара",
 Ul_speed			: "Брзина узтовара",
 Wasted				: "Страћено",
 Tracker			: "Трекер",
 Track_URL			: "URL трекера",
 Track_status			: "Статус трекера",
 Created_on			: "Направљено",
 Save_as			: "Снима се као",
 Comment			: "Коментар",
 add_button			: "Додај датотеку",
 add_url			: "Додај URL",
 ok				: "У реду",
 Cancel				: "Одустани",
 mnu_add			: "Додај торент",
 mnu_remove			: "Уклони",
 mnu_start			: "Покрени",
 mnu_pause			: "Паузирај",
 mnu_stop			: "Заустави",
 mnu_rss			: "RSS Downloader",
 mnu_settings			: "Подешавања",
 mnu_search			: "Претрага",
 mnu_lang			: "Језик",
 torrent_add			: "Додај торент", /*Caption of torrent add box*/
 time_w				: "н ", /*for x weeks*/
 time_d				: "д ", /*for x days remaining*/
 time_h				: "ч ", /*for x hours remaining*/
 time_m				: "м ", /*for x minutes remaining*/
 time_s				: "с ", /*for x seconds remaining*/
 Base_directory			: "Директоријум",
 Number_Peers_min		: "Најмањи број парњака",
 Number_Peers_max		: "Највећи број парњака",
 Tracker_Numwant		: "Жељени број парњака",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting			: "Друга ограничења",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Максимална потрошња меморије",
 Glob_max_files			: "Максималан број отворених датотека",
 Glob_max_http			: "Максималан број отворених НТТР веза",
 Open_label         : "Отвори",
 Other_sett			: "Друго",
 Directory_For_Dl		: "Подразумевани директоријум за низтоваре",
 Check_hash			: "Провери хеш после низтовара",
 Hash				: "Хеш",
 DisableTracker			: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Клијент",
 Flags				: "Ознаке",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Помоћ",
 Speed				: "Брзина",
 Dont_add_tname			: "Don't add torrent's name to path",
 Free_Disk_Space		: "Слободан простор на диску",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath			: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "О програму",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList				: "као листу",
 AsTree				: "као стабло",
 Group				: "Група",
 SuperSeed			: "Супер-сејање",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Укупно",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlViews			: "Views",
 NewView			: "New View",
 MoveView			: {base: "Move view", top: "To top", up: "Up", down: "Down", bottom: "To bottom"},
 RenameView			: "Rename view",
 RemoveActiveViews		: "Remove active views",
 SaveCurrentView		: "Save current view",
 showViewPanel			: "Show Views panel",
 showViewLabelSize		: "Show label size in Views panel",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Додаци",
 plgName			: "Име",
 plgStatus			: "Статус",
 plgLoaded			: "Учитан",
 plgDisabled			: "Not loaded",
 plgVersion			: "Верзија",
 plgAuthor			: "Аутор",
 plgDescr			: "Опис",
 mnu_go				: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Брзи наставак",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Ограничење",
 speedList			: "Speed Popup List (comma-separated)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Прикажи садржај табеле приликом померања",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser			: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast			: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showStateLabelSize		: "Show label size in State panel",
 showLabelSize			: "Show label size in Labels panel",
 showSearchLabelSize		: "Show label size in Search panel",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No				: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details			: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
